@@ -1,13 +1,15 @@
 #' @title Predict Method for `plfd`
 #' 
 #' @param object `plfd` object.
-#' @param x The samples to be predicted.
-#' @param y Vector (optional). Labels of x with value `1` or `2`.
+#' @param x Array, matrix-variate data to be predicted.
+#' @param y Vector (optional), Labels of `x` with value `1` or `2`.
 #' @param ... Ignored currently.
 #' 
-#' @return `list(W, y.hat, mcr)`, wherein `W` refers to the discriminant 
-#' scores, `y.hat` refers to the predicted labels and `mcr` is the misclassification
-#' rate when `y` is available.
+#' @return `list(W, y.hat, mcr)`, \itemize{
+#'  \item `W`: discriminant scores;
+#'  \item `y.hat`: predicted labels;
+#'  \item `mcr`: misclassification rate if parameter `y` is available.
+#' }
 #' @export 
 predict.plfd <- function(object, x, y, ...) {
     stopifnot( object$rDim == NROW(x) )
@@ -25,7 +27,7 @@ predict.plfd <- function(object, x, y, ...) {
       W <- W + apply(x[rIdx, cIdx, , drop=FALSE], 3, function(.) sum((.-M) * B))
     }
 
-    y.hat=ifelse(W>0, 1, 2)
+    y.hat <- ifelse(W>0, 1, 2)
     result <- list(score=W, y.hat=y.hat)
 
     if (!missing(y)) {
